@@ -1,13 +1,14 @@
-# -*- coding: utf-8 -*-
 # Copyright 2012-2015 Ryan "ZDBioHazard" Turner <zdbiohazard2@gmail.com>
 #                2016 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk
 
+from quodlibet import _
 from quodlibet.plugins.songshelpers import each_song, is_writable
 from quodlibet.plugins.songsmenu import SongsMenuPlugin
 from quodlibet.qltk import Icons
@@ -16,15 +17,17 @@ from quodlibet.qltk import Icons
 class EditPlaycount(SongsMenuPlugin):
     PLUGIN_ID = "editplaycount"
     PLUGIN_NAME = _("Edit Playcount")
-    PLUGIN_DESC = _("Edit a song's ~#playcount and ~#skipcount."
-                    "\n\n"
-                    "When multiple songs are selected, counts will be "
-                    "incremented, rather than set."
-                    "\n\n"
-                    "When setting a song's ~#playcount to 0, the "
-                    "~#lastplayed and ~#laststarted entries will be cleared. "
-                    "However, when setting a 0-play song to a positive play "
-                    "count, no play times will be created.")
+    PLUGIN_DESC_MARKUP = _(
+        "Edit a song's <tt>~#playcount</tt> and <tt>~#skipcount.</tt>"
+        "\n\n"
+        "When multiple songs are selected, counts will be "
+        "incremented, rather than set."
+        "\n\n"
+        "When setting a song's <tt>~#playcount</tt> to 0, "
+        "the <tt>~#lastplayed</tt> and <tt>~#laststarted</tt> "
+        "entries will be cleared. "
+        "However, when setting a 0-play song to a positive play "
+        "count, no play times will be created.")
     PLUGIN_ICON = Icons.EDIT
     REQUIRES_ACTION = True
 
