@@ -1,12 +1,12 @@
-# -*- coding: utf-8 -*-
 # Copyright 2012 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 
-class GStreamerPlugin(object):
+class GStreamerPlugin:
     """GStreamer Plugins define an element that gets inserted into the
     GStreamer pipeline before the audio sink and after the playbin.
 
