@@ -14,7 +14,7 @@ from quodlibet import const
 class AboutDialog(Gtk.AboutDialog):
 
     def __init__(self, parent, app):
-        super(AboutDialog, self).__init__()
+        super().__init__()
         self.set_transient_for(parent)
         self.set_program_name(app.name)
         self.set_version(quodlibet.get_build_description())
@@ -25,5 +25,4 @@ class AboutDialog(Gtk.AboutDialog):
         self.set_license_type(Gtk.License.GPL_2_0)
         self.set_translator_credits("\n".join(const.TRANSLATORS))
         self.set_website(const.WEBSITE)
-        self.set_copyright(const.COPYRIGHT + "\n" +
-                           "<%s>" % const.SUPPORT_EMAIL)
+        self.set_copyright(f"{const.COPYRIGHT}\n{const.SUPPORT_EMAIL}")
