@@ -1,4 +1,5 @@
 # Copyright 2005 Joe Wreschnig, Michael Urman
+#           2021 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -6,6 +7,8 @@
 # (at your option) any later version.
 
 from gi.repository import Gtk
+
+from quodlibet.util import escape
 from senf import fsn2text, path2fsn
 
 from quodlibet import _
@@ -19,18 +22,18 @@ class Message(Gtk.MessageDialog, Dialog):
     """A message dialog that destroys itself after it is run, uses
     markup, and defaults to an 'OK' button."""
 
-    def __init__(
-        self, kind, parent, title, description, buttons=Gtk.ButtonsType.OK):
+    def __init__(self, kind, parent, title, description, buttons=Gtk.ButtonsType.OK,
+                 escape_desc=True):
         parent = get_top_parent(parent)
         text = ("<span weight='bold' size='larger'>%s</span>\n\n%s"
-                % (title, description))
-        super(Message, self).__init__(
+                % (escape(title), escape(description) if escape_desc else description))
+        super().__init__(
             transient_for=parent, modal=True, destroy_with_parent=True,
             message_type=kind, buttons=buttons)
         self.set_markup(text)
 
     def run(self, destroy=True):
-        resp = super(Message, self).run()
+        resp = super().run()
         if destroy:
             self.destroy()
         return resp
@@ -44,7 +47,7 @@ class CancelRevertSave(Gtk.MessageDialog, Dialog):
         text = ("<span weight='bold' size='larger'>%s</span>\n\n%s"
                 % (title, description))
         parent = get_top_parent(parent)
-        super(CancelRevertSave, self).__init__(
+        super().__init__(
             transient_for=parent, flags=0,
             message_type=Gtk.MessageType.WARNING,
             buttons=Gtk.ButtonsType.NONE)
@@ -59,7 +62,7 @@ class CancelRevertSave(Gtk.MessageDialog, Dialog):
         self.set_markup(text)
 
     def run(self):
-        resp = super(CancelRevertSave, self).run()
+        resp = super().run()
         self.destroy()
         return resp
 
@@ -67,14 +70,14 @@ class CancelRevertSave(Gtk.MessageDialog, Dialog):
 class ErrorMessage(Message):
     """Like Message, but uses an error-indicating picture."""
     def __init__(self, *args, **kwargs):
-        super(ErrorMessage, self).__init__(
+        super().__init__(
             Gtk.MessageType.ERROR, *args, **kwargs)
 
 
 class WarningMessage(Message):
     """Like Message, but uses an warning-indicating picture."""
     def __init__(self, *args, **kwargs):
-        super(WarningMessage, self).__init__(
+        super().__init__(
             Gtk.MessageType.WARNING, *args, **kwargs)
 
 
@@ -82,17 +85,14 @@ class ConfirmationPrompt(WarningMessage):
     """Dialog to confirm actions, given a parent, title, description, and
        OK-button text"""
 
-    RESPONSE_INVOKE = 1
+    RESPONSE_INVOKE = Gtk.ResponseType.YES
 
-    def __init__(self, parent, title, description, ok_button_text):
-        super(ConfirmationPrompt, self).__init__(
-            get_top_parent(parent),
-            title, description,
-            buttons=Gtk.ButtonsType.NONE)
+    def __init__(self, parent, title, description, ok_button_text,
+                 ok_button_icon=Icons.SYSTEM_RUN):
+        super().__init__(parent, title, description, buttons=Gtk.ButtonsType.NONE)
 
         self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
-        self.add_icon_button(ok_button_text, Icons.SYSTEM_RUN,
-                             self.RESPONSE_INVOKE)
+        self.add_icon_button(ok_button_text, ok_button_icon, self.RESPONSE_INVOKE)
         self.set_default_response(Gtk.ResponseType.CANCEL)
 
 
@@ -105,7 +105,7 @@ class ConfirmFileReplace(WarningMessage):
         fn_format = "<b>%s</b>" % util.escape(fsn2text(path2fsn(path)))
         description = _("Replace %(file-name)s?") % {"file-name": fn_format}
 
-        super(ConfirmFileReplace, self).__init__(
+        super().__init__(
             parent, title, description, buttons=Gtk.ButtonsType.NONE)
 
         self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
