@@ -1,6 +1,6 @@
-# -*- coding: utf-8 -*-
 # Copyright 2012 Christoph Reiter
 #           2016 Nick Boultbee
+#      2018-2019 Fredrik Strupe
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@ from quodlibet.util import print_d
 from quodlibet import config
 
 
-class PlaylistMux(object):
+class PlaylistMux:
     """Provides the PlaylistModel interface combining the song list model and
     the queue one.
 
@@ -61,11 +61,16 @@ class PlaylistMux(object):
         """Switch to the next song"""
 
         keep_songs = config.getboolean("memory", "queue_keep_songs", False)
-        q_ignore = config.getboolean("memory", "queue_ignore", False)
+        q_disable = config.getboolean("memory", "queue_disable", False)
 
         if (self.q.is_empty()
-                or (q_ignore and not (keep_songs and self.q.sourced))):
+                or q_disable
+                or (keep_songs and not self.q.sourced)):
             self.pl.next()
+            if q_disable and self.q.sourced:
+                # The go_to is to make sure the playlist begins playing
+                # when the queue is disabled while being sourced
+                self.go_to(self.pl.current)
         else:
             self.q.next()
         self._check_sourced()
@@ -74,11 +79,14 @@ class PlaylistMux(object):
         """Switch to the next song (action comes from the user)"""
 
         keep_songs = config.getboolean("memory", "queue_keep_songs", False)
-        q_ignore = config.getboolean("memory", "queue_ignore", False)
+        q_disable = config.getboolean("memory", "queue_disable", False)
 
         if (self.q.is_empty()
-                or (q_ignore and not (keep_songs and self.q.sourced))):
+                or q_disable
+                or (keep_songs and not self.q.sourced)):
             self.pl.next_ended()
+            if q_disable and self.q.sourced:
+                self.go_to(self.pl.current)
         else:
             self.q.next_ended()
         self._check_sourced()
@@ -87,10 +95,12 @@ class PlaylistMux(object):
         """Go to the previous song"""
 
         keep_songs = config.getboolean("memory", "queue_keep_songs", False)
-        q_ignore = config.getboolean("memory", "queue_ignore", False)
+        q_disable = config.getboolean("memory", "queue_disable", False)
 
-        if q_ignore or self.pl.sourced or not keep_songs:
+        if q_disable or self.pl.sourced or not keep_songs:
             self.pl.previous()
+            if q_disable and self.q.sourced:
+                self.go_to(self.pl.current)
         else:
             self.q.previous()
         self._check_sourced()
@@ -109,8 +119,9 @@ class PlaylistMux(object):
             assert source in (self.pl, self.q)
             if source is self.q:
                 main, other = other, main
-        other.go_to(None)
         res = main.go_to(song, explicit)
+        if res is not None or not explicit:
+            other.go_to(None)
         self._check_sourced()
         return res
 
@@ -137,7 +148,7 @@ class PlaylistMux(object):
 class TrackCurrentModel(ObjectStore):
 
     def __init__(self, *args, **kwargs):
-        super(TrackCurrentModel, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.__iter = None
 
     last_current = None
@@ -220,11 +231,11 @@ class TrackCurrentModel(ObjectStore):
     def remove(self, iter_):
         if self.__iter and self[iter_].path == self[self.__iter].path:
             self.__iter = None
-        super(TrackCurrentModel, self).remove(iter_)
+        super().remove(iter_)
 
     def clear(self):
         self.__iter = None
-        super(TrackCurrentModel, self).clear()
+        super().clear()
 
     def __contains__(self, song):
         return bool(self.find(song))
@@ -240,7 +251,7 @@ class PlaylistModel(TrackCurrentModel):
     """True in case this model is the source of the currently playing song"""
 
     def __init__(self, order_cls=OrderInOrder):
-        super(PlaylistModel, self).__init__(object)
+        super().__init__(object)
         self.order = order_cls()
 
         # The playorder plugins use paths atm to remember songs so
@@ -306,7 +317,7 @@ class PlaylistModel(TrackCurrentModel):
         self.order.reset(self)
         for signal_id in self.__sigs:
             self.handler_block(signal_id)
-        super(PlaylistModel, self).set(songs)
+        super().set(songs)
         for signal_id in self.__sigs:
             self.handler_unblock(signal_id)
 
